@@ -1,8 +1,7 @@
-from typing import Callable
-
 import zmq
 
 from keios_zmq.log_provider import LogProvider
+from keios_zmq.dispatcher import Dispatcher
 from keios_zmq.zmq_server import ZMQServer
 
 
@@ -10,9 +9,10 @@ class KeiosZMQ(ZMQServer):
     """
     Blocking KeiosZMQ server
     """
-    log = LogProvider.get_logger("keios-zmq-server")
+    log = LogProvider.get_logger("blocking-keios-zmq-server")
 
-    def __init__(self, port: int, message_handler: Callable[[bytearray], bytearray]):
+    def __init__(self, port: int,
+                 message_handler: Dispatcher):
         self._port = port
         self._zmq_context = zmq.Context()
         self._socket = self._zmq_context.socket(zmq.ROUTER)
@@ -24,26 +24,14 @@ class KeiosZMQ(ZMQServer):
     def internal_handler(self):
         while not self.stopped:
             try:
-                addr, msg = self.internal_receive_message()
-                self.log.debug("msg received - identity: {}, data: {}".format(addr, msg))
-                self.internal_send_message(addr, self._message_handler(msg))
+                identity, messages = self.destruct(self._socket.recv_multipart())
+                self.log.debug("Msg received - identity: {}, data: {}".format(identity, messages))
+                self._socket.send_multipart(self.construct(identity, self._message_handler.execute(messages)))
             except zmq.error.ContextTerminated as e:
                 pass  # this error is expected from .close()
 
-    def internal_receive_message(self):
-        """
-        Wraps blocking zmq recv
-        :return:
-        """
-        identity, data = self._socket.recv_multipart()
-        return [identity, data]
-
-    def internal_send_message(self, identity, message):
-        return self._socket.send_multipart([identity,
-                                            message])
-
     def start_server(self):
-        self.log.info(f"blocking-zmq-server started on port: {self._port}")
+        self.log.info(f"Blocking-zmq-server started on port: {self._port}")
         self.internal_handler()
 
     def close(self):
